<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * @author Aybat Duyshokov <duyshokov@gmail.com>
 * @package ow_plugins.birthdays
 * @since 1.0
 */
// "Birthdays" page's route
$router->addRoute(new OW_Route('birthdays_users', 'users/birthdays', 'BASE_CTRL_UserList', 'index'));

        // class that contains all data and functionality to add new type of members listing
        class BIRTHDAYS_UsersPageData implements BASE_CLASS_IusersPageData
        {

            //set menu item for "Birthdays" page
            public function getMenuItem()
            {
                //$language - helps our site to be multilingual
                $language = OW::getLanguage();

                //initializing menu item
                $item = new BASE_MenuItem();

                $item->setLabel($language->text('base', 'user_list_menu_item_birthdays'))
                    ->setKey('birthdays')
                    ->setUrl(OW::getRouter()
                        ->urlForRoute('birthdays_users'))
                    ->setOrder(5)
                    ->setIconClass('ow_ic_calendar');

                if ( $this->isCase() )
                {
                    $item->setActive(true); // activate menu if "Birthdays" selected
                }

                return $item;
            }

            // check if URL is belong to "Birthdays" page
            public function isCase()
            {
                return false !== strstr(OW::getRequest()->getRequestUri(), OW::getRouter()->uriForRoute('birthdays_users'));
            }

            // "Birthdays" page's unique key
            public function getCase()
            {
                return 'birthdays';
            }

            // get data for "Birthdays" user listing
            public function getData( $first, $count )
            {
                $service = BOL_UserService::getInstance();

                //set date bounds for birthdays
                $period = array(
                    'start' => date('Y-m-d'),
                    'end' => date('Y-m-d', strtotime('+7 day'))
                );

                return array(
                    $service->findListByBirthdayPeriod($period['start'], $period['end'], $first, $count), // get users
                    $service->countByBirthdayPeriod($period['start'], $period['end']) // count users
                );
            }
        }

        // register data for "Birthdays" page.
        OW::getRegistry()->addToArray('users_page_data', new BIRTHDAYS_UsersPageData());