<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * @author Aybat Duyshokov <duyshokov@gmail.com>
 * @package ow_plugins.contact_importer.controllers
 * @since 1.0
 */
class CONTACTIMPORTER_CTRL_Admin extends ADMIN_CTRL_Abstract
{	
	public function __construct()
	{
		parent::__construct();
						
		$this->setPageHeading(OW::getLanguage()->text('contact_importer', 'admin_plugin_settings_heading'));
		$this->setPageHeadingIconClass('ow_ic_gear_wheel');
	}

    /**
     * Default action
     */
	public function index()
	{
		$form = new SettingsForm($this);
		
		if(!empty($_POST) && $_POST['which'] == 'yahoo'  && $form->isValid($_POST))
		{
			$data = $form->getValues();
			
			OW::getConfig()->saveConfig('contact_importer', 'yahoo_domain_verification_file', $data['yahoo_domain_verification_file']);
			OW::getConfig()->saveConfig('contact_importer', 'yahoo_consumer_key', $data['yahoo_consumer_key']);
			OW::getConfig()->saveConfig('contact_importer', 'yahoo_consumer_secret', $data['yahoo_consumer_secret']);
			OW::getConfig()->saveConfig('contact_importer', 'yahoo_app_id', $data['yahoo_app_id']);
			
			OW::getFeedback()->info(OW::getLanguage()->text('contact_importer', 'admin_settings_updated'));
			$this->redirect( OW::getRouter()->urlForRoute('contact-importer-admin') );
		}
		$this->addForm($form);
		
		$form2 = new FSettingsForm($this);

		if(!empty($_POST) && $_POST['which'] == 'facebook' && $form2->isValid($_POST))
		{
			$data = $form2->getValues();
			
			OW::getConfig()->saveConfig('contact_importer', 'facebook_api_key', $data['facebook_api_key']);
			OW::getConfig()->saveConfig('contact_importer', 'facebook_app_secret', $data['facebook_app_secret']);

			OW::getFeedback()->info(OW::getLanguage()->text('contact_importer', 'admin_settings_updated'));
			$this->redirect( OW::getRouter()->urlForRoute('contact-importer-admin') );			
		}

		$this->addForm($form2);		
	}
}

class SettingsForm extends Form
{
	public function __construct($ctrl)
	{
		parent::__construct('form');

		$configs = OW::getConfig()->getValues('contact_importer');

		$ctrl->assign('configs', $configs);

		$l = OW::getLanguage();

		
//---------
$textField['yahoo_domain_verification_file'] = new TextField('yahoo_domain_verification_file');

		$textField['yahoo_domain_verification_file']->setLabel($l->text('contact_importer', 'yahoo_domain_verification_file'))
			->setValue( $configs['yahoo_domain_verification_file'] );

		$this->addElement( $textField['yahoo_domain_verification_file'] );
		
//---------		
		
		$textField['yahoo_consumer_key'] = new TextField('yahoo_consumer_key');

		$textField['yahoo_consumer_key']->setLabel($l->text('contact_importer', 'yahoo_consumer_key'))
			->setValue( $configs['yahoo_consumer_key'] );

		$this->addElement( $textField['yahoo_consumer_key'] );

//---------

		$textField['yahoo_consumer_secret'] = new TextField('yahoo_consumer_secret');

		$textField['yahoo_consumer_secret']->setLabel($l->text('contact_importer', 'yahoo_consumer_secret'))
			->setValue( $configs['yahoo_consumer_secret'] );

		$this->addElement( $textField['yahoo_consumer_secret'] );		

//---------

		$textField['yahoo_app_id'] = new TextField('yahoo_app_id');

		$textField['yahoo_app_id']->setLabel($l->text('contact_importer', 'yahoo_app_id'))
			->setValue( $configs['yahoo_app_id'] );

		$this->addElement( $textField['yahoo_app_id'] );

//---------
		
		$submit = new Submit('submit');

		$submit->setValue($l->text('contact_importer', 'save_btn_label'));

		$this->addElement( $submit );
	}
}

class FSettingsForm extends Form
{
	public function __construct($ctrl)
	{
		parent::__construct('form2');

		$configs = OW::getConfig()->getValues('contact_importer');
		
		$ctrl->assign('configs', $configs);

		$l = OW::getLanguage();

		$textField['facebook_api_key'] = new TextField('facebook_api_key');

		$textField['facebook_api_key']->setLabel($l->text('contact_importer', 'facebook_api_key'))
			->setValue( $configs['facebook_api_key'] );

		$this->addElement( $textField['facebook_api_key'] );

//---------

		$textField['facebook_app_secret'] = new TextField('facebook_app_secret');

		$textField['facebook_app_secret']->setLabel($l->text('contact_importer', 'facebook_app_secret'))
			->setValue( $configs['facebook_app_secret'] );

		$this->addElement( $textField['facebook_app_secret'] );		

//---------
		
		$submit = new Submit('submit');

		$submit->setValue($l->text('contact_importer', 'save_btn_label'));

		$this->addElement( $submit );
	}
}