<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Data Access Object for `newsfeed_action` table.
 *
 * @author Sergey Kambalin <greyexpert@gmail.com>
 * @package ow_plugins.newsfeed.bol
 * @since 1.0
 */
class NEWSFEED_BOL_ActionDao extends OW_BaseDao
{
    /**
     * Singleton instance.
     *
     * @var NEWSFEED_BOL_ActionDao
     */
    private static $classInstance;

    /**
     * Returns an instance of class (singleton pattern implementation).
     *
     * @return NEWSFEED_BOL_ActionDao
     */
    public static function getInstance()
    {
        if ( self::$classInstance === null )
        {
            self::$classInstance = new self();
        }

        return self::$classInstance;
    }

    /**
     * @see OW_BaseDao::getDtoClassName()
     *
     */
    public function getDtoClassName()
    {
        return 'NEWSFEED_BOL_Action';
    }

    /**
     * @see OW_BaseDao::getTableName()
     *
     */
    public function getTableName()
    {
        return OW_DB_PREFIX . 'newsfeed_action';
    }

    public function findByFeed( $feedType, $feedId, $count = null )
    {
        $actionFeedDao = NEWSFEED_BOL_ActionFeedDao::getInstance();
        
        $limit = '';
        if ( !empty($count) )
        {
            $limit = "LIMIT 0, " . intval($count);    
        }
        
        $query = 'SELECT action.* FROM ' . $this->getTableName() . ' action 
            INNER JOIN ' . $actionFeedDao->getTableName() . ' action_feed ON action.id=action_feed.actionId
            WHERE action.status=:s AND action_feed.feedType=:ft AND action_feed.feedId=:fi AND action.privacy & :p 
            ORDER BY action.updateTime DESC ' . $limit;
        
        return $this->dbo->queryForObjectList($query, $this->getDtoClassName(), array(
            'ft' => $feedType,
            'fi' => $feedId, 
            's' => NEWSFEED_BOL_Service::ACTION_STATUS_ACTIVE,
            'p' => NEWSFEED_BOL_Service::PRIVACY_FEED));
    }
    
    public function findCountByFeed( $feedType, $feedId )
    {
        $actionFeedDao = NEWSFEED_BOL_ActionFeedDao::getInstance();
        
        $query = 'SELECT COUNT(action.id) FROM ' . $this->getTableName() . ' action 
            INNER JOIN ' . $actionFeedDao->getTableName() . ' action_feed ON action.id=action_feed.actionId
            WHERE action.status=:s AND action_feed.feedType=:ft AND action_feed.feedId=:fi AND action.privacy & :p';  
        
        return (int) $this->dbo->queryForColumn($query, array(
            'ft' => $feedType,
            'fi' => $feedId, 
            's' => NEWSFEED_BOL_Service::ACTION_STATUS_ACTIVE,
            'p' => NEWSFEED_BOL_Service::PRIVACY_FEED));
    }
    
    /**
     * 
     * @param $entityType
     * @param $entityId
     * @return NEWSFEED_BOL_Action
     */
    public function findAction( $entityType, $entityId )
    {
        $example = new OW_Example();
        $example->andFieldEqual('entityType', $entityType);
        $example->andFieldEqual('entityId', $entityId);
        
        return $this->findObjectByExample($example);
    }
    
    public function findByPluginKey( $pluginKey )
    {
        $example = new OW_Example();
        $example->andFieldEqual('pluginKey', $pluginKey);
        
        return $this->findListByExample($example);
    }
    
    public function setStatusByPluginKey( $pluginKey, $status )
    {
        $query = "UPDATE " . $this->getTableName() . " SET `status`=:s WHERE pluginKey=:pk";
        
        $this->dbo->query($query, array(
            's' => $status,
            'pk' => $pluginKey
        ));
    }
    
    public function findByUser( $userId, $count = null )
    {
        $followDao = NEWSFEED_BOL_FollowDao::getInstance();
        $actionFeedDao = NEWSFEED_BOL_ActionFeedDao::getInstance();
        
        $limit = '';
        if ( !empty($count) )
        {
            $limit = "LIMIT 0, " . intval($count);    
        }
        
        $query = 'SELECT DISTINCT action.* FROM ' . $this->getTableName() . ' action 
            INNER JOIN ' . $actionFeedDao->getTableName() . ' action_feed ON action.id=action_feed.actionId
            LEFT JOIN ' . $followDao->getTableName() . ' follow ON action_feed.feedId = follow.feedId AND action_feed.feedType = follow.feedType
            WHERE action.status=:s AND ( 
                ( follow.userId=:u AND action.privacy & :pf ) 
                OR 
                ( action.userId=:u AND action.privacy & :pa )  
                OR
                ( action_feed.feedId=:u AND action_feed.feedType="user" AND action.privacy & :pfeed )
            )  
            ORDER BY action.updateTime DESC ' . $limit;
        
        return $this->dbo->queryForObjectList($query, $this->getDtoClassName(), array(
            'u' => $userId, 
            'pa' => NEWSFEED_BOL_Service::PRIVACY_AUTOR,
            's' => NEWSFEED_BOL_Service::ACTION_STATUS_ACTIVE,
            'pf' => NEWSFEED_BOL_Service::PRIVACY_FOLLOW,
            'pfeed' => NEWSFEED_BOL_Service::PRIVACY_FEED));
    }
    
    public function findCountByUser( $userId )
    {
        $followDao = NEWSFEED_BOL_FollowDao::getInstance();
        $actionFeedDao = NEWSFEED_BOL_ActionFeedDao::getInstance();
        
        $query = 'SELECT COUNT(DISTINCT action.id) FROM ' . $this->getTableName() . ' action 
            INNER JOIN ' . $actionFeedDao->getTableName() . ' action_feed ON action.id=action_feed.actionId
            LEFT JOIN ' . $followDao->getTableName() . ' follow ON action_feed.feedId = follow.feedId AND action_feed.feedType = follow.feedType
            WHERE action.status=:s AND ( 
                ( follow.userId=:u AND action.privacy & :pf ) 
                OR 
                ( action.userId=:u AND action.privacy & :pa )  
                OR
                ( action_feed.feedId=:u AND action_feed.feedType="user" AND action.privacy & :pfeed )
            )';
        
        return $this->dbo->queryForColumn($query, array(
            'u' => $userId, 
            'pa' => NEWSFEED_BOL_Service::PRIVACY_AUTOR,
            's' => NEWSFEED_BOL_Service::ACTION_STATUS_ACTIVE,
            'pf' => NEWSFEED_BOL_Service::PRIVACY_FOLLOW,
            'pfeed' => NEWSFEED_BOL_Service::PRIVACY_FEED));
    }
    
    public function findSiteFeed( $count = null )
    {
        $limit = '';
        if ( !empty($count) )
        {
            $limit = "LIMIT 0, " . intval($count);    
        }
        
        $query = 'SELECT DISTINCT * FROM ' . $this->getTableName() . ' WHERE status=:s AND privacy & :pa ORDER BY updateTime DESC ' . $limit;
        
        return $this->dbo->queryForObjectList($query, $this->getDtoClassName(), array(
            'pa' => NEWSFEED_BOL_Service::PRIVACY_SITE, 's' => NEWSFEED_BOL_Service::ACTION_STATUS_ACTIVE));
    }
    
    public function findSiteFeedCount()
    {
        $query = 'SELECT COUNT(DISTINCT id) FROM ' . $this->getTableName() . ' WHERE status=:s AND privacy & :pa ORDER BY updateTime DESC';
        
        return (int) $this->dbo->queryForColumn($query, array(
            'pa' => NEWSFEED_BOL_Service::PRIVACY_SITE, 's' => NEWSFEED_BOL_Service::ACTION_STATUS_ACTIVE));
    }
    
    public function findExpired( $inactivePeriod )
    {
        $example = new OW_Example();
        $example->andFieldLessThan('updateTime', time() - (int) $inactivePeriod);
        
        return $this->findObjectByExample($example);
    }
}