<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 *
 * @author Sergey Kambalin <greyexpert@gmail.com>
 * @package ow_plugins.newsfeed.classes
 * @since 1.0
 */
class NEWSFEED_CLASS_Action
{
    private $properties = array();
    
    public function __construct()
    {
        $this->properties['createTime'] = time();
        $this->properties['updateTime'] = time();
    }
    
    public function setDataValue( $name, $value )
    {
        $this->properties['data'][$name] = $value;
    }
    
    public function getDataValue( $name )
    {
        if ( empty($this->properties['data'][$name]) )
        {
            return null;
        }
        
        return $this->properties['data'][$name];
    }
    
    public function setEntity( $entityType, $entityId )
    {
        $this->properties['entityType'] = $entityType;
        $this->properties['entityId'] = $entityId;
    }
    
    /**
     * 
     * @return NEWSFEED_CLASS_Identifier
     */
    public function getEntity()
    {
        if ( empty($this->properties['entityType']) || empty($this->properties['entityId']) )
        {
            return null;
        }
        
        return new NEWSFEED_CLASS_Identifier($this->properties['entityType'], $this->properties['entityId']);
    }
    
    public function setCreateTime( $time )
    {
        $this->properties['createTime'] = $time;
    }
    
    public function getCreateTime()
    {
        return empty($this->properties['createTime']) ? null : (int) $this->properties['createTime'];
    }
    
    public function setUserId( $userId )
    {
        $this->properties['userId'] = $userId;
    }
    
    public function getUserId()
    {
        return $this->properties['userId'];
    }
    
    public function setUpdateTime( $time )
    {
        $this->properties['updateTime'] = (int) $time;
    }
    
    public function getUpdateTime()
    {
        return $this->properties['updateTime'];
    }
    
    public function getId()
    {
        return $this->properties['id'];
    }
    
    public function setPluginKey( $key )
    {
        $this->properties['pluginKey'] = $key;
    }
    
    public function getPluginKey()
    {
        return $this->properties['pluginKey'];
    }
    
    public function setPrivacy( $privacy )
    {
        $this->properties['privacy'] = (int) $privacy;
    }
    
    public function getPrivacy( $privacy )
    {
        return $this->properties['privacy'];
    }
    
    public function setStatus( $status )
    {
        $this->properties['status'] = trim($privacy);
    }
    
    public function getStatus( $privacy )
    {
        return $this->properties['status'];
    }
    
    /**
     * 
     * @return NEWSFEED_BOL_Action
     */
    public function saveToDto()
    {
        $props = $this->properties;
        $props['data'] = json_encode($props['data']);
        
        $dto = new NEWSFEED_BOL_Action();
        
        foreach ( $props as $prop => $value )
        {
            $dto->$prop = $value;
        }
        
        return $dto;
    }
    
   
    public function loadFromDto( NEWSFEED_BOL_Action $dto )
    {
        $this->properties['id'] = (int) $dto->id;
        $this->properties['updateTime'] = (int) $dto->updateTime;
        $this->properties['data'] = json_decode($dto->data, true);
        $this->properties['entityId'] = (int) $dto->entityId;
        $this->properties['entityType'] = $dto->entityType;
        $this->properties['userId'] = (int) $dto->userId;
        $this->properties['createTime'] = (int) $dto->createTime;
        $this->properties['status'] = $dto->status;
        $this->properties['pluginKey'] = $dto->pluginKey;
        $this->properties['privacy'] = (int) $dto->privacy;
    }
}