<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 *
 * @author Sergey Kambalin <greyexpert@gmail.com>
 * @package ow_plugins.newsfeed.controllers
 * @since 1.0
 */
class NEWSFEED_CTRL_Admin extends ADMIN_CTRL_Abstract
{

    /**
     * Default action
     */
    public function index()
    {
        $language = OW::getLanguage();

        $this->setPageHeading($language->text('newsfeed', 'admin_page_heading'));
        $this->setPageTitle($language->text('newsfeed', 'admin_page_title'));
        $this->setPageHeadingIconClass('ow_ic_comment');
        
        $configs = OW::getConfig()->getValues('newsfeed');

        $form = new NEWSFEED_ConfigSaveForm($configs);

        $this->addForm($form);

        if ( OW::getRequest()->isPost() && $form->isValid($_POST) )
        {
            if ( $form->process($_POST) )
            {
                OW::getFeedback()->info($language->text('newsfeed', 'settings_updated'));
                $this->redirect(OW::getRouter()->urlForRoute('newsfeed_admin_settings'));    
            }
        }
    }
}

/**
 * Save photo configuration form class
 */
class NEWSFEED_ConfigSaveForm extends Form
{

    /**
     * Class constructor
     *
     */
    public function __construct( $configs )
    {
        parent::__construct('NEWSFEED_ConfigSaveForm');

        $language = OW::getLanguage();

        $field = new CheckboxField('allow_likes');
        $field->setLabel($language->text('newsfeed', 'admin_allow_likes_label'));
        $field->setValue($configs['allow_likes']);
        $this->addElement($field);

        $field = new TextField('comments_count');
        $field->setValue($configs['comments_count']);
        $field->setRequired(true);
        $validator = new IntValidator();
        $field->addValidator($validator);
        $field->setLabel($language->text('newsfeed', 'admin_comments_count_label'));
        $this->addElement($field);

        // submit
        $submit = new Submit('save');
        $submit->setValue($language->text('newsfeed', 'admin_save_btn'));
        $this->addElement($submit);
    }

    /**
     * Updates photo plugin configuration
     *
     * @return boolean
     */
    public function process( $data )
    {
        $config = OW::getConfig();

        $config->saveConfig('newsfeed', 'allow_likes', intval( (bool) $data['allow_likes']));
        $config->saveConfig('newsfeed', 'comments_count', $data['comments_count']);

        return true;
    }
}